# `libdlr`: Imaginary time calculations using the Discrete Lehmann Representation

Authors: [Jason Kaye](https://github.com/jasonkaye) and [Hugo UR Strand](https://github.com/HugoStrand) (2021)

`libdlr` is a library providing Fortran subroutines to build and work with the
discrete Lehmann representation (DLR) of single particle imaginary time Green's functions,
as well as a stand-alone Python module `pydlr` implementing the same functionality.

For more information see the [documentation](https://libdlr.readthedocs.io), and the references below.

For a C++ implementation of the DLR, please see
[cppdlr](https://github.com/flatironinstitute/cppdlr). For a Julia
implementation, see [Lehmann.jl](https://github.com/numericaleft/Lehmann.jl).

## Citation

If this library helps you to create software or publications, please let
us know, and cite

- our repository: https://github.com/jasonkaye/libdlr
- [libdlr: Efficient imaginary time calculations using the discrete Lehmann representation, Jason Kaye, Kun Chen, and Hugo U.R. Strand, Comput. Phys. Commun. 280, 108458, 2022.](https://www.sciencedirect.com/science/article/pii/S0010465522001771) \[[arXiv:2110.06765](https://arxiv.org/abs/2110.06765)\]
- [Discrete Lehmann representation of imaginary time Green's functions, Jason Kaye, Kun Chen, and Olivier Parcollet, Phys. Rev. B 105, 235115, 2022.](https://journals.aps.org/prb/abstract/10.1103/PhysRevB.105.235115) \[[arXiv:2107.13094](https://arxiv.org/abs/2107.13094)\]

## Contact

Please email jkaye@flatironinstitute.org with any and all questions.

## License

`libdlr` is licensed under the Apache License, Version 2.0, for more information see the `LICENSE` file.
